Style

Struct Style 

pub struct Style { /* private fields */ }
Styling map for defining widget appearance.

Implementations

Source

impl Style

pub fn new() -> Self

Create a new empty style.

pub fn from_values( values: impl IntoIterator<Item = (&'static str, StyleVal)>, ) -> Self

Create a style from an array of strings and style values.

pub fn with_value(self, name: &'static str, value: StyleVal) -> Self

Insert a style value with the given name into the style map and return the new style.

pub fn get(&self, name: &'static str) -> Option<StyleVal>

Get a style value by name. Returns None if the value name does not exist.

pub fn get_color(&self, name: &'static str) -> Option<Color>

Get a color style value by name. Returns None if the value name does not exist.

pub fn get_gradient(&self, name: &'static str) -> Option<Gradient>

Get a gradient style value by name. Returns None if the value name does not exist.

pub fn get_brush(&self, name: &'static str) -> Option<Brush>

Get a brush style value by name. Returns None if the value name does not exist.

pub fn get_float(&self, name: &'static str) -> Option<f32>

Get a float style value by name. Returns None if the value name does not exist.

pub fn get_int(&self, name: &'static str) -> Option<i32>

Get an int style value by name. Returns None if the value name does not exist.

pub fn get_uint(&self, name: &'static str) -> Option<u32>

Get an unsized int style value by name. Returns None if the value name does not exist.

pub fn get_bool(&self, name: &'static str) -> Option<bool>

Get a bool style value by name. Returns None if the value name does not exist.